1.17.0 “Donkey Surfer” — Rucio 1.2 documentation

# 1.17.0 “Donkey Surfer”

## General

### Features

- Release management: Cleanup unused packages in pip-requires #45
- Transfers: FTS3 transfertool: proxy delegation function #1177

### Enhancements

- Functional tests: Functional tests: dev container fails on userpass authentication #1156
- Transfers: Features for user data transfers in CMS #1179

### Bugs

- Clients: Sorting of replicas in list_replicas #668
- Core & Internals: policy_filter decorator makes methods fail in certain cases #1143
- Core & Internals: Permission : Fix update_replica_state for ATLAS #1228

## Clients

### Features

- Clients: Switch bin/rucio download to downloadclient #669
- Clients: Switch bin/rucio upload to uploadclient #670

### Enhancements

- Clients: Client : localSite is not filled in traces for downloadclient #1263
- Clients: Automatic protocol failover for upload #468
- Clients: bin/rucio upload/download still have a lot of return FAILURE statements #567

### Bugs

- Clients: rucio download does not respect protocol order #1222
- Clients: Rucio download randomly shuffles the rses, even if they are retrieved in a sorted way #490
- Clients: Traceback error in rucio upload #501

## WebUI

### Enhancements

- WebUI: hide accounts without quota and usage from manage quota page #1216

### Bugs

- WebUI: WebUI: UUID not correctly set for files #1227